@@ -1159,6 +1159,8 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_NO_CXX14_STD_EXCHANGE);
    PRINT_MACRO(BOOST_NO_CXX14_VARIABLE_TEMPLATES);
    PRINT_MACRO(BOOST_NO_CXX17_FOLD_EXPRESSIONS);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_OPTIONAL);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_STRING_VIEW);
    PRINT_MACRO(BOOST_NO_CXX17_IF_CONSTEXPR);
    PRINT_MACRO(BOOST_NO_CXX17_INLINE_VARIABLES);
    PRINT_MACRO(BOOST_NO_CXX17_ITERATOR_TRAITS);
@@ -1237,6 +1239,8 @@ void print_boost_macros()
 
 
 
+
+
    // END GENERATED BLOCK
 
    PRINT_MACRO(BOOST_INTEL);
