@@ -7,8 +7,8 @@
 #  Copyright (c) 2017 Adam Wulkiewicz, Lodz, Poland
 #
 #  Copyright (c) 2018, Oracle and/or its affiliates.
+#  Contributed and/or modified by Vissarion Fysikopoulos, on behalf of Oracle
 #  Contributed and/or modified by Adam Wulkiewicz, on behalf of Oracle
-# 
 #  Use, modification and distribution is subject to the Boost Software License,
 #  Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
 #  http://www.boost.org/LICENSE_1_0.txt)
@@ -97,12 +97,12 @@ call_doxygen()
 
 algorithms = ["append", "assign", "make", "clear"
     , "area", "buffer", "centroid", "convert", "correct", "covered_by"
-    , "convex_hull", "crosses", "densify", "difference", "disjoint", "distance" 
+    , "convex_hull", "crosses", "densify", "difference", "discrete_frechet_distance","discrete_hausdorff_distance","disjoint", "distance" 
     , "envelope", "equals", "expand", "for_each", "is_empty"
     , "is_simple", "is_valid", "intersection", "intersects", "length"
     , "num_geometries", "num_interior_rings", "num_points"
     , "num_segments", "overlaps", "perimeter", "relate", "relation"
-    , "reverse", "simplify", "sym_difference", "touches"
+    , "reverse","simplify", "sym_difference", "touches"
     , "transform", "union", "unique", "within"]
 
 access_functions = ["get", "set", "exterior_ring", "interior_rings"
@@ -140,13 +140,13 @@ strategies = ["area::cartesian", "area::spherical", "area::geographic"
     , "distance::pythagoras_point_box", "distance::haversine"
     , "distance::cross_track", "distance::cross_track_point_box"
     , "distance::projected_point"
-    , "within::winding", "within::franklin", "within::crossings_multiply"
     , "simplify::douglas_peucker"
     , "side::side_by_triangle", "side::side_by_cross_track"
     , "side::spherical_side_formula", "side::geographic"
     , "transform::inverse_transformer", "transform::map_transformer"
     , "transform::rotate_transformer", "transform::scale_transformer"
     , "transform::translate_transformer", "transform::matrix_transformer"
+    , "within::winding", "within::franklin", "within::crossings_multiply"
     ]
     
 views = ["box_view", "segment_view"
@@ -188,6 +188,7 @@ for i in views:
 model_to_quickbook2("d2_1_1point__xy", "point_xy")
 
 group_to_quickbook("arithmetic")
+group_to_quickbook("dsv")
 group_to_quickbook("enum")
 group_to_quickbook("register")
 group_to_quickbook("svg")
@@ -199,7 +200,7 @@ class_to_quickbook2("de9im_1_1mask", "de9im_mask")
 class_to_quickbook2("de9im_1_1static__mask", "de9im_static_mask")
 
 os.chdir("index")
-execfile("make_qbk.py")
+exec(compile(open("make_qbk.py", "rb").read(), "make_qbk.py", 'exec'))
 os.chdir("..")
 
 # Clean up generated intermediate files
