@@ -7,6 +7,7 @@
 // See accompanying file LICENSE_1_0.txt or copy at
 // http://www.boost.org/LICENSE_1_0.txt
 
+#define _CRT_SECURE_NO_WARNINGS
 
 #include <boost/filesystem.hpp>
 #include <boost/filesystem/fstream.hpp>
@@ -18,6 +19,7 @@
 #include <set>
 #include <algorithm>
 #include <climits>
+#include <cstdlib>
 
 namespace fs = boost::filesystem;
 
@@ -2049,9 +2051,9 @@ static std::string module_cmake_target( std::string module )
 
 static void output_module_cmake_report( std::string module )
 {
-    std::replace( module.begin(), module.end(), '/', '~' );
+    std::cout << "# Generated by boostdep --cmake " << module << "\n\n";
 
-    std::cout << "# Generated file. Do not edit.\n\n";
+    std::replace( module.begin(), module.end(), '/', '~' );
 
     collect_primary_dependencies a1;
     output_module_primary_report( module, a1, false, false );
@@ -2293,6 +2295,87 @@ static void output_directory_subset_report( std::string const & module, std::set
     }
 }
 
+// list_buildable_dependencies
+
+struct list_buildable_dependencies_actions: public module_overview_actions
+{
+    std::set< std::string > buildable_;
+
+    std::set< std::string > deps_;
+    bool headers_;
+
+    list_buildable_dependencies_actions(): headers_()
+    {
+    }
+
+    void begin()
+    {
+        std::cout << "# Generated by boostdep --list-buildable-dependencies\n\n";
+    }
+
+    void end()
+    {
+    }
+
+    void module_start( std::string const & module )
+    {
+        deps_.clear();
+        headers_ = false;
+
+        if( buildable_.count( module ) )
+        {
+            std::cout << module << " =";
+        }
+    }
+
+    void module_end( std::string const & module )
+    {
+        if( buildable_.count( module ) )
+        {
+            if( headers_ )
+            {
+                std::cout << " headers";
+            }
+
+            for( std::set< std::string >::iterator i = deps_.begin(); i != deps_.end(); ++i )
+            {
+                std::cout << " " << *i;
+            }
+
+            std::cout << " ;\n";
+        }
+    }
+
+    void module2( std::string const & module )
+    {
+        if( module == "(unknown)" ) return;
+
+        if( buildable_.count( module ) == 0 )
+        {
+            headers_ = true;
+        }
+        else
+        {
+            deps_.insert( module );
+        }
+    }
+};
+
+static void list_buildable_dependencies()
+{
+    list_buildable_dependencies_actions actions;
+
+    for( std::set< std::string >::iterator i = s_modules.begin(); i != s_modules.end(); ++i )
+    {
+        if( fs::exists( module_build_path( *i ) ) && fs::exists( module_source_path( *i ) ) )
+        {
+            actions.buildable_.insert( *i );
+        }
+    }
+
+    output_module_overview_report( actions );
+}
+
 //
 
 static bool find_boost_root()
@@ -2317,6 +2400,11 @@ static bool find_boost_root()
     return false;
 }
 
+static bool is_boost_root( fs::path const & p )
+{
+    return fs::exists( p / "Jamroot" );
+}
+
 int main( int argc, char const* argv[] )
 {
     if( argc < 2 )
@@ -2330,6 +2418,7 @@ int main( int argc, char const* argv[] )
             "    boostdep [--track-sources] [--track-tests] --list-dependencies\n"
             "    boostdep --list-exceptions\n"
             "    boostdep --list-missing-headers\n"
+            "    boostdep --list-buildable-dependencies\n"
             "\n"
             "    boostdep [options] --module-overview\n"
             "    boostdep [options] --module-levels\n"
@@ -2345,7 +2434,8 @@ int main( int argc, char const* argv[] )
             "    boostdep --pkgconfig <module> <version> [<var>=<value>] [<var>=<value>]...\n"
             "    boostdep [options] --subset-for <directory>\n"
             "\n"
-            "    [options]: [--[no-]track-sources] [--[no-]track-tests]\n"
+            "    [options]: [--boost-root <path-to-boost>]\n"
+            "               [--[no-]track-sources] [--[no-]track-tests]\n"
             "               [--html-title <title>] [--html-footer <footer>]\n"
             "               [--html-stylesheet <stylesheet>] [--html-prefix <prefix>]\n"
             "               [--html]\n";
@@ -2353,10 +2443,50 @@ int main( int argc, char const* argv[] )
         return -1;
     }
 
-    if( !find_boost_root() )
+    bool root_set = false;
+
+    for( int i = 0; i < argc; ++i )
     {
-        std::cerr << "boostdep: Could not find Boost root.\n";
-        return -2;
+        std::string option = argv[ i ];
+
+        if( option == "--boost-root" )
+        {
+            if( i + 1 < argc )
+            {
+                fs::path p( argv[ ++i ] );
+
+                if( is_boost_root( p ) )
+                {
+                    fs::current_path( p );
+                    root_set = true;
+                }
+                else
+                {
+                    std::cerr << "'" << p.string() << "': not a valid Boost root.\n";
+                    return -2;
+                }
+            }
+            else
+            {
+                std::cerr << "'" << option << "': missing argument.\n";
+                return -2;
+            }
+        }
+    }
+
+    if( !root_set && !find_boost_root() )
+    {
+        char const * env_root = std::getenv( "BOOST_ROOT" );
+
+        if( env_root && is_boost_root( env_root ) )
+        {
+            fs::current_path( env_root );
+        }
+        else
+        {
+            std::cerr << "boostdep: Could not find Boost root.\n";
+            return -2;
+        }
     }
 
     try
@@ -2382,7 +2512,11 @@ int main( int argc, char const* argv[] )
     {
         std::string option = argv[ i ];
 
-        if( option == "--list-modules" )
+        if( option == "--boost-root" )
+        {
+            ++i;
+        }
+        else if( option == "--list-modules" )
         {
             list_modules();
         }
@@ -2561,6 +2695,11 @@ int main( int argc, char const* argv[] )
 
             break;
         }
+        else if( option == "--list-buildable-dependencies" )
+        {
+            enable_secondary( secondary, true, false );
+            list_buildable_dependencies();
+        }
         else if( s_modules.count( option ) )
         {
             output_module_primary_report( option, html, track_sources, track_tests );
